/*
    Copyright  1995-2001, The AROS Development Team. All rights reserved.
    $Id: getcatalogstru.c,v 1.2 2007/04/10 18:33:44 itix Exp $

    Desc: GetLocaleStrU() - Get a builtin system string.
    Lang: english
*/

/* ---- locale.library/UCS4_GetCatalogStr ----
 *
 *   NAME   
 *        UCS4_GetCatalogStr -- get a localized wide string (V51)
 *
 *   SYNOPSIS
 *        string = UCS4_GetLocaleStr(catalog, stringNum, defaultString);
 *
 *        CONST_WSTRPTR UCS4_GetLocaleStr(struct Catalog *, ULONG, CONST_WSTRPTR);
 *
 *   FUNCTION
 *        This function will return the string specified by the
 *        stringNum from the given message catalog, or the defaultString
 *        if the string could not be found.
 *
 *        If the catalog == NULL, then the defaultString will also be returned.
 *
 *   INPUTS
 *        catalog       - Message catalog to search. May be NULL.
 *        stringNum     - ID of the string to find.
 *        defaultString - String to return in case catalog is NULL or string
 *                        could not be found.
 *
 *   RESULT
 *        A pointer to a READ ONLY NULL terminated wide string. This string
 *        pointer is valid as long as the catalog remains open.
 *
 *   NOTES
 *        In the catalogs strings are always in the native byte order but
 *        implementation does not pay attention to the default strings.
 *
 *   SEE ALSO
 *        GetCatalogStr()
 *
 */

#include "locale_intern.h"

CONST ULONG *GetCatalogStrU(struct Catalog *catalog, ULONG stringNum, CONST ULONG *defaultString, struct LocaleBase *LocaleBase)
{
	CONST ULONG *str = defaultString;

	if (catalog && catalog->cat_CodeSet == CODESET_UTF32)
	{
		struct CatStr *cs = IntCat(catalog)->ic_CatStrings;
		ULONG	 i, numstrings = IntCat(catalog)->ic_NumStrings;

		for(i = 0; i < numstrings; i++, cs++)
		{
			if(cs->cs_Id == stringNum)
			{
				str = (ULONG *)cs->cs_String;
				break;
			}
			else
			{
				if((IntCat(catalog)->ic_Flags & ICF_INORDER) && (cs->cs_Id > stringNum))
				{
					break;
				}
			}
		}
	}

	return str;
}
